# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-03-22 23:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('timerboard', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='timer',
            name='details',
            field=models.CharField(default='', max_length=254),
        ),
        migrations.AlterField(
            model_name='timer',
            name='objective',
            field=models.CharField(default='', max_length=254),
        ),
        migrations.AlterField(
            model_name='timer',
            name='planet_moon',
            field=models.CharField(default='', max_length=254),
        ),
        migrations.AlterField(
            model_name='timer',
            name='structure',
            field=models.CharField(default='', max_length=254),
        ),
        migrations.AlterField(
            model_name='timer',
            name='system',
            field=models.CharField(default='', max_length=254),
        ),
    ]
