# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-10-16 01:35
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('services', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='discordauthtoken',
            name='user',
        ),
        migrations.DeleteModel(
            name='DiscordAuthToken',
        ),
    ]
