# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-09-02 06:07
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('services', '0002_auto_20161016_0135'),
    ]

    operations = [
        migrations.DeleteModel(
            name='GroupCache',
        ),
    ]
