# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-09-10 05:42
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('authentication', '0005_delete_perms'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='authservicesinfo',
            name='discourse_password',
        ),
        migrations.RemoveField(
            model_name='authservicesinfo',
            name='forum_password',
        ),
        migrations.RemoveField(
            model_name='authservicesinfo',
            name='ipboard_password',
        ),
        migrations.RemoveField(
            model_name='authservicesinfo',
            name='ips4_password',
        ),
        migrations.RemoveField(
            model_name='authservicesinfo',
            name='jabber_password',
        ),
        migrations.RemoveField(
            model_name='authservicesinfo',
            name='market_password',
        ),
        migrations.RemoveField(
            model_name='authservicesinfo',
            name='mumble_password',
        ),
        migrations.RemoveField(
            model_name='authservicesinfo',
            name='smf_password',
        ),
        migrations.RemoveField(
            model_name='authservicesinfo',
            name='xenforo_password',
        ),
    ]
