{% extends "allianceauth/base.html" %}
{% load i18n %}

{% block page_title %}{% trans "Help" %}{% endblock page_title %}

{% block content %}
    <div class="col-lg-12">

        <h1 class="page-header text-center">{%  trans "Help" %}</h1>

        <div class="container-fluid">
            <div class="embed-responsive embed-responsive-16by9">
                <iframe class="embed-responsive-item" src="https://allianceauth.readthedocs.io/en/latest/features/"></iframe>
            </div>
        </div>
    </div>
{% endblock content %}

